#ifndef SPELLCHECKER_H
#define SPELLCHECKER_H

#include <qobject.h>
#include <qstringlist.h>
#include <qsyntaxhighlighter.h>

#include <map>

class QTimer;
class AspellSpeller;
class AspellConfig;
class HtmlDocument;
class ConfigFile;
class UinsList;
class QPopupMenu;
class Chat;
class CustomInput;

class SpellChecker : public QObject
{
    Q_OBJECT

    private:
        QTimer* myWakeupTimer;
        std::map<QString, AspellSpeller*> checkers; 
        AspellConfig* spellConfig;
        
        QString beginMark;

        bool IsTagMyOwn( HtmlDocument&, int );
        void UpdateChat( CustomInput* edit, QString text );
        void SaveConfig();

    public:
        ConfigFile* config;

        SpellChecker();
        ~SpellChecker();
        QStringList NotCheckedLanguages();
        QStringList CheckedLanguages();
        bool AddCheckedLang( QString& name ); 
        void RemoveCheckedLang( QString& name ); 
        void ChangeMarkColor( const QColor& );
        void BuildMarkTag();
        bool BuildCheckers();

    public slots:
        void ChatCreated( const UinsList& );
        void CleanMessage( Chat* );

    private slots:
        void ExecuteChecking ();
};

class SpellLighter : QSyntaxHighlighter
{
    public:
        SpellLighter (QTextEdit * textEdit);

        virtual int highlightParagraph ( const QString & text, int endStateOfLastPara );
};

extern SpellChecker* spellcheck;

#endif
